package javax.swing.text.html;

import java.io.ObjectInputStream;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import javax.swing.text.StyleContext;
import javax.swing.text.AttributeSet;
import javax.swing.text.StyleConstants;
import java.util.Hashtable;

public class HTML
{
    private static final Hashtable<String, HTML.Tag> tagHashtable;
    private static final Hashtable<Object, HTML.Tag> scMapping;
    public static final String NULL_ATTRIBUTE_VALUE = "#DEFAULT";
    private static final Hashtable<String, HTML.Attribute> attHashtable;
    
    public HTML() {
    }
    
    public static HTML.Tag[] getAllTags() {
        HTML.Tag[] array = new HTML.Tag[HTML.Tag.allTags.length];
        System.arraycopy(HTML.Tag.allTags, 0, array, 0, HTML.Tag.allTags.length);
        return array;
    }
    
    public static HTML.Tag getTag(String key) {
        HTML.Tag tag = (HTML.Tag)HTML.tagHashtable.get(key);
        return (tag == null) ? null : tag;
    }
    
    static HTML.Tag getTagForStyleConstantsKey(StyleConstants key) {
        return (HTML.Tag)HTML.scMapping.get(key);
    }
    
    public static int getIntegerAttributeValue(AttributeSet set, HTML.Attribute attribute, int intValue) {
        String s = (String)set.getAttribute(attribute);
        if (s != null) {
            try {
                intValue = (int)Integer.valueOf(s);
            }
            catch (NumberFormatException ex) {
            }
        }
        return intValue;
    }
    
    public static HTML.Attribute[] getAllAttributeKeys() {
        HTML.Attribute[] array = new HTML.Attribute[HTML.Attribute.allAttributes.length];
        System.arraycopy(HTML.Attribute.allAttributes, 0, array, 0, HTML.Attribute.allAttributes.length);
        return array;
    }
    
    public static HTML.Attribute getAttributeKey(String key) {
        HTML.Attribute attribute = (HTML.Attribute)HTML.attHashtable.get(key);
        if (attribute == null) {
            return null;
        }
        return attribute;
    }
    
    static {
        tagHashtable = new Hashtable(73);
        scMapping = new Hashtable(8);
        for (int i = 0; i < HTML.Tag.allTags.length; ++i) {
            HTML.tagHashtable.put(HTML.Tag.allTags[i].toString(), HTML.Tag.allTags[i]);
            StyleContext.registerStaticAttributeKey(HTML.Tag.allTags[i]);
        }
        StyleContext.registerStaticAttributeKey(HTML.Tag.IMPLIED);
        StyleContext.registerStaticAttributeKey(HTML.Tag.CONTENT);
        StyleContext.registerStaticAttributeKey(HTML.Tag.COMMENT);
        for (int j = 0; j < HTML.Attribute.allAttributes.length; ++j) {
            StyleContext.registerStaticAttributeKey(HTML.Attribute.allAttributes[j]);
        }
        StyleContext.registerStaticAttributeKey("#DEFAULT");
        HTML.scMapping.put(StyleConstants.Bold, HTML.Tag.B);
        HTML.scMapping.put(StyleConstants.Italic, HTML.Tag.I);
        HTML.scMapping.put(StyleConstants.Underline, HTML.Tag.U);
        HTML.scMapping.put(StyleConstants.StrikeThrough, HTML.Tag.STRIKE);
        HTML.scMapping.put(StyleConstants.Superscript, HTML.Tag.SUP);
        HTML.scMapping.put(StyleConstants.Subscript, HTML.Tag.SUB);
        HTML.scMapping.put(StyleConstants.FontFamily, HTML.Tag.FONT);
        HTML.scMapping.put(StyleConstants.FontSize, HTML.Tag.FONT);
        attHashtable = new Hashtable(77);
        for (int k = 0; k < HTML.Attribute.allAttributes.length; ++k) {
            HTML.attHashtable.put(HTML.Attribute.allAttributes[k].toString(), HTML.Attribute.allAttributes[k]);
        }
    }
    
    public static class Tag
    {
        boolean blockTag;
        boolean breakTag;
        String name;
        boolean unknown;
        public static final HTML.Tag A;
        public static final HTML.Tag ADDRESS;
        public static final HTML.Tag APPLET;
        public static final HTML.Tag AREA;
        public static final HTML.Tag B;
        public static final HTML.Tag BASE;
        public static final HTML.Tag BASEFONT;
        public static final HTML.Tag BIG;
        public static final HTML.Tag BLOCKQUOTE;
        public static final HTML.Tag BODY;
        public static final HTML.Tag BR;
        public static final HTML.Tag CAPTION;
        public static final HTML.Tag CENTER;
        public static final HTML.Tag CITE;
        public static final HTML.Tag CODE;
        public static final HTML.Tag DD;
        public static final HTML.Tag DFN;
        public static final HTML.Tag DIR;
        public static final HTML.Tag DIV;
        public static final HTML.Tag DL;
        public static final HTML.Tag DT;
        public static final HTML.Tag EM;
        public static final HTML.Tag FONT;
        public static final HTML.Tag FORM;
        public static final HTML.Tag FRAME;
        public static final HTML.Tag FRAMESET;
        public static final HTML.Tag H1;
        public static final HTML.Tag H2;
        public static final HTML.Tag H3;
        public static final HTML.Tag H4;
        public static final HTML.Tag H5;
        public static final HTML.Tag H6;
        public static final HTML.Tag HEAD;
        public static final HTML.Tag HR;
        public static final HTML.Tag HTML;
        public static final HTML.Tag I;
        public static final HTML.Tag IMG;
        public static final HTML.Tag INPUT;
        public static final HTML.Tag ISINDEX;
        public static final HTML.Tag KBD;
        public static final HTML.Tag LI;
        public static final HTML.Tag LINK;
        public static final HTML.Tag MAP;
        public static final HTML.Tag MENU;
        public static final HTML.Tag META;
        static final HTML.Tag NOBR;
        public static final HTML.Tag NOFRAMES;
        public static final HTML.Tag OBJECT;
        public static final HTML.Tag OL;
        public static final HTML.Tag OPTION;
        public static final HTML.Tag P;
        public static final HTML.Tag PARAM;
        public static final HTML.Tag PRE;
        public static final HTML.Tag SAMP;
        public static final HTML.Tag SCRIPT;
        public static final HTML.Tag SELECT;
        public static final HTML.Tag SMALL;
        public static final HTML.Tag SPAN;
        public static final HTML.Tag STRIKE;
        public static final HTML.Tag S;
        public static final HTML.Tag STRONG;
        public static final HTML.Tag STYLE;
        public static final HTML.Tag SUB;
        public static final HTML.Tag SUP;
        public static final HTML.Tag TABLE;
        public static final HTML.Tag TD;
        public static final HTML.Tag TEXTAREA;
        public static final HTML.Tag TH;
        public static final HTML.Tag TITLE;
        public static final HTML.Tag TR;
        public static final HTML.Tag TT;
        public static final HTML.Tag U;
        public static final HTML.Tag UL;
        public static final HTML.Tag VAR;
        public static final HTML.Tag IMPLIED;
        public static final HTML.Tag CONTENT;
        public static final HTML.Tag COMMENT;
        static final HTML.Tag[] allTags;
        
        public Tag() {
        }
        
        protected Tag(String s) {
            this(s, false, false);
        }
        
        protected Tag(String name, boolean breakTag, boolean blockTag) {
            this.name = name;
            this.breakTag = breakTag;
            this.blockTag = blockTag;
        }
        
        public boolean isBlock() {
            return this.blockTag;
        }
        
        public boolean breaksFlow() {
            return this.breakTag;
        }
        
        public boolean isPreformatted() {
            return this == HTML.Tag.PRE || this == HTML.Tag.TEXTAREA;
        }
        
        @Override
        public String toString() {
            return this.name;
        }
        
        boolean isParagraph() {
            return this == HTML.Tag.P || this == HTML.Tag.IMPLIED || this == HTML.Tag.DT || this == HTML.Tag.H1 || this == HTML.Tag.H2 || this == HTML.Tag.H3 || this == HTML.Tag.H4 || this == HTML.Tag.H5 || this == HTML.Tag.H6;
        }
        
        static {
            A = new HTML.Tag("a");
            ADDRESS = new HTML.Tag("address");
            APPLET = new HTML.Tag("applet");
            AREA = new HTML.Tag("area");
            B = new HTML.Tag("b");
            BASE = new HTML.Tag("base");
            BASEFONT = new HTML.Tag("basefont");
            BIG = new HTML.Tag("big");
            BLOCKQUOTE = new HTML.Tag("blockquote", true, true);
            BODY = new HTML.Tag("body", true, true);
            BR = new HTML.Tag("br", true, false);
            CAPTION = new HTML.Tag("caption");
            CENTER = new HTML.Tag("center", true, false);
            CITE = new HTML.Tag("cite");
            CODE = new HTML.Tag("code");
            DD = new HTML.Tag("dd", true, true);
            DFN = new HTML.Tag("dfn");
            DIR = new HTML.Tag("dir", true, true);
            DIV = new HTML.Tag("div", true, true);
            DL = new HTML.Tag("dl", true, true);
            DT = new HTML.Tag("dt", true, true);
            EM = new HTML.Tag("em");
            FONT = new HTML.Tag("font");
            FORM = new HTML.Tag("form", true, false);
            FRAME = new HTML.Tag("frame");
            FRAMESET = new HTML.Tag("frameset");
            H1 = new HTML.Tag("h1", true, true);
            H2 = new HTML.Tag("h2", true, true);
            H3 = new HTML.Tag("h3", true, true);
            H4 = new HTML.Tag("h4", true, true);
            H5 = new HTML.Tag("h5", true, true);
            H6 = new HTML.Tag("h6", true, true);
            HEAD = new HTML.Tag("head", true, true);
            HR = new HTML.Tag("hr", true, false);
            HTML = new HTML.Tag("html", true, false);
            I = new HTML.Tag("i");
            IMG = new HTML.Tag("img");
            INPUT = new HTML.Tag("input");
            ISINDEX = new HTML.Tag("isindex", true, false);
            KBD = new HTML.Tag("kbd");
            LI = new HTML.Tag("li", true, true);
            LINK = new HTML.Tag("link");
            MAP = new HTML.Tag("map");
            MENU = new HTML.Tag("menu", true, true);
            META = new HTML.Tag("meta");
            NOBR = new HTML.Tag("nobr");
            NOFRAMES = new HTML.Tag("noframes", true, true);
            OBJECT = new HTML.Tag("object");
            OL = new HTML.Tag("ol", true, true);
            OPTION = new HTML.Tag("option");
            P = new HTML.Tag("p", true, true);
            PARAM = new HTML.Tag("param");
            PRE = new HTML.Tag("pre", true, true);
            SAMP = new HTML.Tag("samp");
            SCRIPT = new HTML.Tag("script");
            SELECT = new HTML.Tag("select");
            SMALL = new HTML.Tag("small");
            SPAN = new HTML.Tag("span");
            STRIKE = new HTML.Tag("strike");
            S = new HTML.Tag("s");
            STRONG = new HTML.Tag("strong");
            STYLE = new HTML.Tag("style");
            SUB = new HTML.Tag("sub");
            SUP = new HTML.Tag("sup");
            TABLE = new HTML.Tag("table", false, true);
            TD = new HTML.Tag("td", true, true);
            TEXTAREA = new HTML.Tag("textarea");
            TH = new HTML.Tag("th", true, true);
            TITLE = new HTML.Tag("title", true, true);
            TR = new HTML.Tag("tr", false, true);
            TT = new HTML.Tag("tt");
            U = new HTML.Tag("u");
            UL = new HTML.Tag("ul", true, true);
            VAR = new HTML.Tag("var");
            IMPLIED = new HTML.Tag("p-implied");
            CONTENT = new HTML.Tag("content");
            COMMENT = new HTML.Tag("comment");
            allTags = new HTML.Tag[] { HTML.Tag.A, HTML.Tag.ADDRESS, HTML.Tag.APPLET, HTML.Tag.AREA, HTML.Tag.B, HTML.Tag.BASE, HTML.Tag.BASEFONT, HTML.Tag.BIG, HTML.Tag.BLOCKQUOTE, HTML.Tag.BODY, HTML.Tag.BR, HTML.Tag.CAPTION, HTML.Tag.CENTER, HTML.Tag.CITE, HTML.Tag.CODE, HTML.Tag.DD, HTML.Tag.DFN, HTML.Tag.DIR, HTML.Tag.DIV, HTML.Tag.DL, HTML.Tag.DT, HTML.Tag.EM, HTML.Tag.FONT, HTML.Tag.FORM, HTML.Tag.FRAME, HTML.Tag.FRAMESET, HTML.Tag.H1, HTML.Tag.H2, HTML.Tag.H3, HTML.Tag.H4, HTML.Tag.H5, HTML.Tag.H6, HTML.Tag.HEAD, HTML.Tag.HR, HTML.Tag.HTML, HTML.Tag.I, HTML.Tag.IMG, HTML.Tag.INPUT, HTML.Tag.ISINDEX, HTML.Tag.KBD, HTML.Tag.LI, HTML.Tag.LINK, HTML.Tag.MAP, HTML.Tag.MENU, HTML.Tag.META, HTML.Tag.NOBR, HTML.Tag.NOFRAMES, HTML.Tag.OBJECT, HTML.Tag.OL, HTML.Tag.OPTION, HTML.Tag.P, HTML.Tag.PARAM, HTML.Tag.PRE, HTML.Tag.SAMP, HTML.Tag.SCRIPT, HTML.Tag.SELECT, HTML.Tag.SMALL, HTML.Tag.SPAN, HTML.Tag.STRIKE, HTML.Tag.S, HTML.Tag.STRONG, HTML.Tag.STYLE, HTML.Tag.SUB, HTML.Tag.SUP, HTML.Tag.TABLE, HTML.Tag.TD, HTML.Tag.TEXTAREA, HTML.Tag.TH, HTML.Tag.TITLE, HTML.Tag.TR, HTML.Tag.TT, HTML.Tag.U, HTML.Tag.UL, HTML.Tag.VAR };
            javax.swing.text.html.HTML.getTag("html");
        }
    }
    
    public static class UnknownTag extends HTML.Tag implements Serializable
    {
        public UnknownTag(String s) {
            super(s);
        }
        
        @Override
        public int hashCode() {
            return this.toString().hashCode();
        }
        
        @Override
        public boolean equals(Object o) {
            return o instanceof HTML.UnknownTag && this.toString().equals(o.toString());
        }
        
        private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
            objectOutputStream.defaultWriteObject();
            objectOutputStream.writeBoolean(this.blockTag);
            objectOutputStream.writeBoolean(this.breakTag);
            objectOutputStream.writeBoolean(this.unknown);
            objectOutputStream.writeObject(this.name);
        }
        
        private void readObject(ObjectInputStream objectInputStream) throws ClassNotFoundException, IOException {
            objectInputStream.defaultReadObject();
            this.blockTag = objectInputStream.readBoolean();
            this.breakTag = objectInputStream.readBoolean();
            this.unknown = objectInputStream.readBoolean();
            this.name = (String)objectInputStream.readObject();
        }
    }
    
    public static final class Attribute
    {
        private String name;
        public static final HTML.Attribute SIZE;
        public static final HTML.Attribute COLOR;
        public static final HTML.Attribute CLEAR;
        public static final HTML.Attribute BACKGROUND;
        public static final HTML.Attribute BGCOLOR;
        public static final HTML.Attribute TEXT;
        public static final HTML.Attribute LINK;
        public static final HTML.Attribute VLINK;
        public static final HTML.Attribute ALINK;
        public static final HTML.Attribute WIDTH;
        public static final HTML.Attribute HEIGHT;
        public static final HTML.Attribute ALIGN;
        public static final HTML.Attribute NAME;
        public static final HTML.Attribute HREF;
        public static final HTML.Attribute REL;
        public static final HTML.Attribute REV;
        public static final HTML.Attribute TITLE;
        public static final HTML.Attribute TARGET;
        public static final HTML.Attribute SHAPE;
        public static final HTML.Attribute COORDS;
        public static final HTML.Attribute ISMAP;
        public static final HTML.Attribute NOHREF;
        public static final HTML.Attribute ALT;
        public static final HTML.Attribute ID;
        public static final HTML.Attribute SRC;
        public static final HTML.Attribute HSPACE;
        public static final HTML.Attribute VSPACE;
        public static final HTML.Attribute USEMAP;
        public static final HTML.Attribute LOWSRC;
        public static final HTML.Attribute CODEBASE;
        public static final HTML.Attribute CODE;
        public static final HTML.Attribute ARCHIVE;
        public static final HTML.Attribute VALUE;
        public static final HTML.Attribute VALUETYPE;
        public static final HTML.Attribute TYPE;
        public static final HTML.Attribute CLASS;
        public static final HTML.Attribute STYLE;
        public static final HTML.Attribute LANG;
        public static final HTML.Attribute FACE;
        public static final HTML.Attribute DIR;
        public static final HTML.Attribute DECLARE;
        public static final HTML.Attribute CLASSID;
        public static final HTML.Attribute DATA;
        public static final HTML.Attribute CODETYPE;
        public static final HTML.Attribute STANDBY;
        public static final HTML.Attribute BORDER;
        public static final HTML.Attribute SHAPES;
        public static final HTML.Attribute NOSHADE;
        public static final HTML.Attribute COMPACT;
        public static final HTML.Attribute START;
        public static final HTML.Attribute ACTION;
        public static final HTML.Attribute METHOD;
        public static final HTML.Attribute ENCTYPE;
        public static final HTML.Attribute CHECKED;
        public static final HTML.Attribute MAXLENGTH;
        public static final HTML.Attribute MULTIPLE;
        public static final HTML.Attribute SELECTED;
        public static final HTML.Attribute ROWS;
        public static final HTML.Attribute COLS;
        public static final HTML.Attribute DUMMY;
        public static final HTML.Attribute CELLSPACING;
        public static final HTML.Attribute CELLPADDING;
        public static final HTML.Attribute VALIGN;
        public static final HTML.Attribute HALIGN;
        public static final HTML.Attribute NOWRAP;
        public static final HTML.Attribute ROWSPAN;
        public static final HTML.Attribute COLSPAN;
        public static final HTML.Attribute PROMPT;
        public static final HTML.Attribute HTTPEQUIV;
        public static final HTML.Attribute CONTENT;
        public static final HTML.Attribute LANGUAGE;
        public static final HTML.Attribute VERSION;
        public static final HTML.Attribute N;
        public static final HTML.Attribute FRAMEBORDER;
        public static final HTML.Attribute MARGINWIDTH;
        public static final HTML.Attribute MARGINHEIGHT;
        public static final HTML.Attribute SCROLLING;
        public static final HTML.Attribute NORESIZE;
        public static final HTML.Attribute ENDTAG;
        public static final HTML.Attribute COMMENT;
        static final HTML.Attribute MEDIA;
        static final HTML.Attribute[] allAttributes;
        
        Attribute(String name) {
            this.name = name;
        }
        
        @Override
        public String toString() {
            return this.name;
        }
        
        static {
            SIZE = new HTML.Attribute("size");
            COLOR = new HTML.Attribute("color");
            CLEAR = new HTML.Attribute("clear");
            BACKGROUND = new HTML.Attribute("background");
            BGCOLOR = new HTML.Attribute("bgcolor");
            TEXT = new HTML.Attribute("text");
            LINK = new HTML.Attribute("link");
            VLINK = new HTML.Attribute("vlink");
            ALINK = new HTML.Attribute("alink");
            WIDTH = new HTML.Attribute("width");
            HEIGHT = new HTML.Attribute("height");
            ALIGN = new HTML.Attribute("align");
            NAME = new HTML.Attribute("name");
            HREF = new HTML.Attribute("href");
            REL = new HTML.Attribute("rel");
            REV = new HTML.Attribute("rev");
            TITLE = new HTML.Attribute("title");
            TARGET = new HTML.Attribute("target");
            SHAPE = new HTML.Attribute("shape");
            COORDS = new HTML.Attribute("coords");
            ISMAP = new HTML.Attribute("ismap");
            NOHREF = new HTML.Attribute("nohref");
            ALT = new HTML.Attribute("alt");
            ID = new HTML.Attribute("id");
            SRC = new HTML.Attribute("src");
            HSPACE = new HTML.Attribute("hspace");
            VSPACE = new HTML.Attribute("vspace");
            USEMAP = new HTML.Attribute("usemap");
            LOWSRC = new HTML.Attribute("lowsrc");
            CODEBASE = new HTML.Attribute("codebase");
            CODE = new HTML.Attribute("code");
            ARCHIVE = new HTML.Attribute("archive");
            VALUE = new HTML.Attribute("value");
            VALUETYPE = new HTML.Attribute("valuetype");
            TYPE = new HTML.Attribute("type");
            CLASS = new HTML.Attribute("class");
            STYLE = new HTML.Attribute("style");
            LANG = new HTML.Attribute("lang");
            FACE = new HTML.Attribute("face");
            DIR = new HTML.Attribute("dir");
            DECLARE = new HTML.Attribute("declare");
            CLASSID = new HTML.Attribute("classid");
            DATA = new HTML.Attribute("data");
            CODETYPE = new HTML.Attribute("codetype");
            STANDBY = new HTML.Attribute("standby");
            BORDER = new HTML.Attribute("border");
            SHAPES = new HTML.Attribute("shapes");
            NOSHADE = new HTML.Attribute("noshade");
            COMPACT = new HTML.Attribute("compact");
            START = new HTML.Attribute("start");
            ACTION = new HTML.Attribute("action");
            METHOD = new HTML.Attribute("method");
            ENCTYPE = new HTML.Attribute("enctype");
            CHECKED = new HTML.Attribute("checked");
            MAXLENGTH = new HTML.Attribute("maxlength");
            MULTIPLE = new HTML.Attribute("multiple");
            SELECTED = new HTML.Attribute("selected");
            ROWS = new HTML.Attribute("rows");
            COLS = new HTML.Attribute("cols");
            DUMMY = new HTML.Attribute("dummy");
            CELLSPACING = new HTML.Attribute("cellspacing");
            CELLPADDING = new HTML.Attribute("cellpadding");
            VALIGN = new HTML.Attribute("valign");
            HALIGN = new HTML.Attribute("halign");
            NOWRAP = new HTML.Attribute("nowrap");
            ROWSPAN = new HTML.Attribute("rowspan");
            COLSPAN = new HTML.Attribute("colspan");
            PROMPT = new HTML.Attribute("prompt");
            HTTPEQUIV = new HTML.Attribute("http-equiv");
            CONTENT = new HTML.Attribute("content");
            LANGUAGE = new HTML.Attribute("language");
            VERSION = new HTML.Attribute("version");
            N = new HTML.Attribute("n");
            FRAMEBORDER = new HTML.Attribute("frameborder");
            MARGINWIDTH = new HTML.Attribute("marginwidth");
            MARGINHEIGHT = new HTML.Attribute("marginheight");
            SCROLLING = new HTML.Attribute("scrolling");
            NORESIZE = new HTML.Attribute("noresize");
            ENDTAG = new HTML.Attribute("endtag");
            COMMENT = new HTML.Attribute("comment");
            MEDIA = new HTML.Attribute("media");
            allAttributes = new HTML.Attribute[] { HTML.Attribute.FACE, HTML.Attribute.COMMENT, HTML.Attribute.SIZE, HTML.Attribute.COLOR, HTML.Attribute.CLEAR, HTML.Attribute.BACKGROUND, HTML.Attribute.BGCOLOR, HTML.Attribute.TEXT, HTML.Attribute.LINK, HTML.Attribute.VLINK, HTML.Attribute.ALINK, HTML.Attribute.WIDTH, HTML.Attribute.HEIGHT, HTML.Attribute.ALIGN, HTML.Attribute.NAME, HTML.Attribute.HREF, HTML.Attribute.REL, HTML.Attribute.REV, HTML.Attribute.TITLE, HTML.Attribute.TARGET, HTML.Attribute.SHAPE, HTML.Attribute.COORDS, HTML.Attribute.ISMAP, HTML.Attribute.NOHREF, HTML.Attribute.ALT, HTML.Attribute.ID, HTML.Attribute.SRC, HTML.Attribute.HSPACE, HTML.Attribute.VSPACE, HTML.Attribute.USEMAP, HTML.Attribute.LOWSRC, HTML.Attribute.CODEBASE, HTML.Attribute.CODE, HTML.Attribute.ARCHIVE, HTML.Attribute.VALUE, HTML.Attribute.VALUETYPE, HTML.Attribute.TYPE, HTML.Attribute.CLASS, HTML.Attribute.STYLE, HTML.Attribute.LANG, HTML.Attribute.DIR, HTML.Attribute.DECLARE, HTML.Attribute.CLASSID, HTML.Attribute.DATA, HTML.Attribute.CODETYPE, HTML.Attribute.STANDBY, HTML.Attribute.BORDER, HTML.Attribute.SHAPES, HTML.Attribute.NOSHADE, HTML.Attribute.COMPACT, HTML.Attribute.START, HTML.Attribute.ACTION, HTML.Attribute.METHOD, HTML.Attribute.ENCTYPE, HTML.Attribute.CHECKED, HTML.Attribute.MAXLENGTH, HTML.Attribute.MULTIPLE, HTML.Attribute.SELECTED, HTML.Attribute.ROWS, HTML.Attribute.COLS, HTML.Attribute.DUMMY, HTML.Attribute.CELLSPACING, HTML.Attribute.CELLPADDING, HTML.Attribute.VALIGN, HTML.Attribute.HALIGN, HTML.Attribute.NOWRAP, HTML.Attribute.ROWSPAN, HTML.Attribute.COLSPAN, HTML.Attribute.PROMPT, HTML.Attribute.HTTPEQUIV, HTML.Attribute.CONTENT, HTML.Attribute.LANGUAGE, HTML.Attribute.VERSION, HTML.Attribute.N, HTML.Attribute.FRAMEBORDER, HTML.Attribute.MARGINWIDTH, HTML.Attribute.MARGINHEIGHT, HTML.Attribute.SCROLLING, HTML.Attribute.NORESIZE, HTML.Attribute.MEDIA, HTML.Attribute.ENDTAG };
        }
    }
}
